package Qt::Script::QScriptClassPropertyIterator;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QScriptClassPropertyIterator
# file     : QtScript/qscriptclasspropertyiterator.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_04';


# FIXME: operator overload


1;

=head1 NAME

Qt::Script::QScriptClassPropertyIterator

=head1 PUBLIC METHODS

=over

=item   ~QScriptClassPropertyIterator()

=item  QFlags<QScriptValue::PropertyFlag> flags()

=item  bool hasNext()

=item  bool hasPrevious()

=item  uint id()

=item  QScriptString name()

=item  void next()

=item  QScriptValue object()

=item  void previous()

=item  void toBack()

=item  void toFront()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2012 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
