package Qt::Script;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: Qt::Script
# file     : null

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_04';

require XSLoader;
XSLoader::load('Qt::Script', $VERSION);

# FIXME: operator overload


1;

=head1 NAME

Qt::Script

=head1 PUBLIC METHODS

=over


=back

=head1 ENUM VALUES

=over

=item QtDebugMsg

=item QtWarningMsg

=item QtCriticalMsg

=item QtFatalMsg

=item QtSystemMsg

=item Q_COMPLEX_TYPE

=item Q_PRIMITIVE_TYPE

=item Q_STATIC_TYPE

=item Q_MOVABLE_TYPE

=item Q_DUMMY_TYPE

=item LicensedCore

=item LicensedGui

=item LicensedNetwork

=item LicensedOpenGL

=item LicensedOpenVG

=item LicensedSql

=item LicensedMultimedia

=item LicensedXml

=item LicensedXmlPatterns

=item LicensedHelp

=item LicensedScript

=item LicensedScriptTools

=item LicensedQt3SupportLight

=item LicensedQt3Support

=item LicensedSvg

=item LicensedDeclarative

=item LicensedActiveQt

=item LicensedTest

=item LicensedDBus


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2012 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
