package Qt::Script::Template;
package Qt::Script::Template::T000;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QList<QScriptValue>
# file     : typemap_template

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_04';


# FIXME: operator overload


1;

=head1 NAME

Qt::Script::Template::T000

=head1 PUBLIC METHODS

=over

=item   QList<QScriptValue>()

=item   QList<QScriptValue>(const QList<QScriptValue> & l)

=item   ~QList<QScriptValue>()

=item  void append(const QScriptValue & t)

=item  void append(const QList<QScriptValue> & t)

=item  const QScriptValue & at(int i)

=item  void clear()

=item  void detach()

=item  void detachShared()

=item  void insert(int i, const QScriptValue & t)

=item  bool isDetached()

=item  bool isEmpty()

=item  bool isSharedWith(const QList<QScriptValue> & other)

=item  void move(int from, int to)

=item  QList<QScriptValue> operator=(const QList<QScriptValue> & l)

=item  QScriptValue & operator[](int i)

=item  void prepend(const QScriptValue & t)

=item  void removeAt(int i)

=item  void replace(int i, const QScriptValue & t)

=item  void reserve(int size)

=item  void setSharable(bool shrable)

=item  int size()

=item  void swap(int i, int j)

=item  QScriptValue takeAt(int i)

=item  QScriptValue takeFirst()

=item  QScriptValue takeLast()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2012 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut

